"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostgresDBRunner = void 0;
const node_fetch_1 = __importDefault(require("node-fetch"));
const child_process_1 = require("child_process");
const testcontainers_1 = require("testcontainers");
const db_runner_abstract_1 = require("./db-runner.abstract");
class PostgresDBRunner extends db_runner_abstract_1.DbRunnerAbstract {
    static startContainer(options) {
        const version = process.env.TEST_PGSQL_VERSION || options.version || '9.6.8';
        const container = new testcontainers_1.GenericContainer(`postgres:${version}`)
            .withEnvironment({
            POSTGRES_USER: 'test',
            POSTGRES_DB: 'test',
            POSTGRES_PASSWORD: 'test',
        })
            .withExposedPorts(5432)
            // .withHealthCheck({
            //   test: 'pg_isready -U root -d model_test',
            //   interval: 2 * 1000,
            //   timeout: 500,
            //   retries: 3
            // })
            // .withWaitStrategy(Wait.forHealthCheck())
            // Postgresql do fast shutdown on start for db applying
            .withStartupTimeout(10 * 1000);
        if (options.volumes) {
            const binds = options.volumes.map(v => ({ source: v.source, target: v.target, mode: v.bindMode }));
            container.withBindMounts(binds);
        }
        return container.start();
    }
    static async loadEcom(db) {
        const ecom = await (await (0, node_fetch_1.default)('https://cube.dev/downloads/ecom-dump-d3-example.sql')).text();
        (0, child_process_1.execSync)(`psql postgresql://test:test@${db.getHost()}:${db.getMappedPort(5432)}/test`, { input: ecom });
    }
}
exports.PostgresDBRunner = PostgresDBRunner;
//# sourceMappingURL=postgres.js.map